==> libgwenhywfar_3.3.5.orig.tar.gz: gwenhywfar-3.3.5/src/os/windows/process_p.h <==
/***************************************************************************
  $RCSfile$
                             -------------------
    cvs         : $Id$
    begin       : Sun Dec 28 2003
    copyright   : (C) 2003 by Martin Preuss
    email       : martin@libchipcard.de


 ***************************************************************************
 *                                                                         *
 *   This library is free software; you can redistribute it and/or         *
 *   modify it under the terms of the GNU Lesser General Public            *
 *   License as published by the Free Software Foundation; either          *
 *   version 2.1 of the License, or (at your option) any later version.    *
 *                                                                         *
 *   This library is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *
 *   Lesser General Public License for more details.                       *
 *                                                                         *
 *   You should have received a copy of the GNU Lesser General Public      *
 *   License along with this library; if not, write to the Free Software   *
 *   Foundation, Inc., 59 Temple Place, Suite 330, Boston,                 *
 *   MA  02111-1307  USA                                                   *
 *                                                                         *
 ***************************************************************************/


#ifndef GWENHYWFAR_PROCESS_P_H
#define GWENHYWFAR_PROCESS_P_H "$Id"

#include <gwenhywfar/process.h>
#include <windows.h>


#define GWEN_PROCESS_EXITCODE_ABORT 253

#define GWEN_BUFFEREDIO_WINFILE_TIMEOUT 20000


struct GWEN_PROCESS {
  PROCESS_INFORMATION processInfo;
  GWEN_PROCESS_STATE state;
  int result;
  int finished;
  uint32_t pflags;
  GWEN_BUFFEREDIO *stdIn;
  GWEN_BUFFEREDIO *stdOut;
  GWEN_BUFFEREDIO *stdErr;
};

GWEN_PROCESS_STATE GWEN_Process_MakeState(GWEN_PROCESS *pr, DWORD status);


struct GWEN_BUFFEREDIO_WINFILE {
  HANDLE fd;
};
typedef struct GWEN_BUFFEREDIO_WINFILE GWEN_BUFFEREDIO_WINFILE;

int GWEN_BufferedIO_WinFile__Read(GWEN_BUFFEREDIO *dm,
                                             char *buffer,
                                             int *size,
                                             int timeout);

int GWEN_BufferedIO_WinFile__Write(GWEN_BUFFEREDIO *dm,
                                              const char *buffer,
                                              int *size,
                                              int timeout);
int GWEN_BufferedIO_WinFile__Close(GWEN_BUFFEREDIO *dm);
void GWENHYWFAR_CB GWEN_BufferedIO_WinFile_FreeData(void *bp, void *p);

GWEN_BUFFEREDIO *GWEN_BufferedIO_WinFile_new(HANDLE fd);








#endif

==> libgwenhywfar_5.6.0.orig.tar.gz: gwenhywfar-5.6.0/src/os/windows/process_p.h <==
/***************************************************************************
    begin       : Sun Dec 28 2003
    copyright   : (C) 2003-2010 by Martin Preuss
    email       : martin@libchipcard.de


 ***************************************************************************
 *                                                                         *
 *   This library is free software; you can redistribute it and/or         *
 *   modify it under the terms of the GNU Lesser General Public            *
 *   License as published by the Free Software Foundation; either          *
 *   version 2.1 of the License, or (at your option) any later version.    *
 *                                                                         *
 *   This library is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *
 *   Lesser General Public License for more details.                       *
 *                                                                         *
 *   You should have received a copy of the GNU Lesser General Public      *
 *   License along with this library; if not, write to the Free Software   *
 *   Foundation, Inc., 59 Temple Place, Suite 330, Boston,                 *
 *   MA  02111-1307  USA                                                   *
 *                                                                         *
 ***************************************************************************/


#ifndef GWENHYWFAR_PROCESS_P_H
#define GWENHYWFAR_PROCESS_P_H "$Id"

#include <gwenhywfar/process.h>
#include <windows.h>


#define GWEN_PROCESS_EXITCODE_ABORT 253



struct GWEN_PROCESS {
  PROCESS_INFORMATION processInfo;
  GWEN_PROCESS_STATE state;
  int result;
  int finished;
  uint32_t pflags;
  GWEN_SYNCIO *stdIn;
  GWEN_SYNCIO *stdOut;
  GWEN_SYNCIO *stdErr;
};

GWEN_PROCESS_STATE GWEN_Process_MakeState(GWEN_PROCESS *pr, DWORD status);




#endif
